@@ -7,7 +7,10 @@ test_that("autounbox", {
   expect_true(inherits(.list$b, "scalar"))
 
   .list <- list(3, 4)
-  expect_error(autounbox(.list))
+  expect_error(autounbox(.list), NA)
+
+  .list <- list(a = galicia)
+  expect_error(autounbox(.list), NA)
 
   .list <- list(a = T)
   .list <- autounbox(.list)
@@ -19,5 +22,18 @@ test_that("autounbox", {
                          b = list(a = 1)))
   .list <- autounbox(.list)
   expect_true(inherits(.list$b$b$a, "scalar"))
+
+  .list <- list(3,
+                list(4,
+                     list(a = 1)))
+  .list <- autounbox(.list)
+    expect_true(inherits(.list[[2]][[2]][[1]], "scalar"))
+
+
+  .list <- list(a = 3, b = NULL)
+  .list <- autounbox(.list)
+
+  .list <- list(a = 3, b = NULL)
+  .list <- autounbox(.list)
 })
 
